      SUBROUTINE POISVR (IPRINT, NAMLEN, NSTATS, NXCELL, NYCELL,
     $     KSBRG, XCELLD, YCELLD, RMISSV, VALMIN, VALMAX, RMAXIT,
     $     TLRNCE, ROMEGA, MVARBL, MSBRGN, XSTATL, YSTATL, STAVAL,
     $     MSTATS, JRGRID, FRCFNC, OUTMAT, JFLAG)
C
C NAME -- POISSON STATION VALUE DISTRIBUTION FOR VARIABLE
C
C DESCRIPTION -- CALCULATES FULL GRID DISTRIBUTION OF STATION VALUES
C        IN ONE SUBREGION VIA POISSON METHOD FOR EACH VARIABLE
C
C PROGRAMMER -- J. ANDERSON, D. DURRAN/SAI JULY 1976
C
C MODIFIER -- L. REID/SAI MAY 1977
C
C MODIFIER -- DC WHITNEY /SAI JULY 1977
C
C INPUTS --
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         NAMLEN    I  NUMBER OF WORDS IN A NAME
C         NSTATS    I  NUMBER OF STATIONS
C         NXCELL    I  NUMBER OF X-CELLS
C         NYCELL    I  NUMBER OF Y-CELLS
C         KSBRG     I  SUBREGION NUMBER
C         XCELLD    R  CELL LENGTH IN X-DIRECTION
C         YCELLD    R  CELL LENGTH IN Y-DIRECTION
C         RMISSV    R  MISSING VALUE INDICATOR
C         VALMIN    R  MINIMUM ALLOWABLE VALUE
C         VALMAX    R  MAXIMUM ALLOWABLE VALUE
C         RMAXIT    R  MAXIMUM NUMBER OF ITERATIONS
C         TLRNCE    R  CONVERGENCE CRITERION
C         ROMEGA    R  'OMEGA' (OTHERWISE UNDEFINED)
C         MVARBL    I  VARIABLE NAME
C         MSBRGN    I SUBREGION NAME
C         XSTATL    R  STATION LOCATION X-COORDINATES
C         YSTATL    R  STATION LOCATION Y-COORDINATES
C         STAVAL    R  STATION VALUES
C         MSTATS    I  STATION NAMES
C         JRGRID    I  REGIONAL GRID
C         FRCFNC    R  FORCING FUNCTION
C
C OUTPUTS --
C         OUTMAT    R  THE OUTPUT VALUES
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES --
C         NFORCE    I  NUMBER OF ITERATIONS ON FORCING FUNCTION
C         NMAXIT    I  NUMBER OF ITERATIONS ON POISSON SOLUTION
C         NXCLM1    I  NUMBER OF X-CELLS MINUS ONE
C         NYCLM1    I  NUMBER OF Y-CELLS MINUS ONE
C         NWORDS    I  NUMBER OF WORDS FOR FORCING FUNCTION INITIALIZATION
C         KSTAT     I  STATION NUMBER
C         KXLOC     I  STATION X-CELL NUMBER
C         KYLOC     I  STATION Y-CELL NUMBER
C         OMEGML    R  MULTIPLIER FOR 'OMEGA'
C         VALLRG    R  ARBITRARILY LARGE VALUE
C         ZEROES    R  FLOATING POINT ZERO
C         WOMEGA    R  ADJUSTED VALUE FOR 'OMEGA'
C         CLAREA    R  AREA OF GRID CELL
C         VALLOW    R  LOWEST STATION VALUE
C         VALDEV    R  DEVIATION IN CELL VALUE
C         RESMAX    R  MAXIMUM RESIDUAL VALUE
C
C ROUTINES CALLED --
C          SINVAL    SETS ENTIRE ARRAY TO A SINGLE VALUE
C
C ERROR CONDITIONS --
C         -11       NO VALID STATIONS -- FIRST TRY
C         -12       NO VALID STATIONS -- SECOND TRY
C         -13       NO VALID STATIONS -- THIRD TRY
C         -16       CONVERGENCE FAILURE ON INITIAL TRIAL
C         -17       CONVERGENCE FAILURE ON FORCING TRIAL
C
C OTHER INFORMATION --
C
C
C
C SET DIMENSIONS OF EXTERNAL ARRAYS
C
Ctcm  DIMENSION MVARBL(NAMLEN)
      character*4 MVARBL(NAMLEN)
Ctcm  DIMENSION MSBRGN(NAMLEN)
      character*4 MSBRGN(NAMLEN)
      DIMENSION XSTATL(NSTATS)
      DIMENSION YSTATL(NSTATS)
      DIMENSION STAVAL(NSTATS)
Ctcm  DIMENSION MSTATS(NAMLEN, NSTATS)
      character*4 MSTATS(NAMLEN, NSTATS)
      DIMENSION JRGRID(NXCELL, NYCELL)
      DIMENSION FRCFNC(NXCELL, NYCELL)
      DIMENSION OUTMAT(NXCELL, NYCELL)
C
C SET SOME INTERNAL VARIABLES
C
      DATA NFORCE /8/
      DATA OMEGML /0.25/
      DATA ZEROES /0.0/
      DATA IHI /0/, ILOW /0/
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
C
C CONVERT AND CHECK NUMBER OF ITERATIONS
C
      NMAXIT = IFIX(RMAXIT + 0.5)
C
C SET PARAMETERS FOR POISSON SOLUTION
C
      WOMEGA = OMEGML * ROMEGA
      NXCLM1 = NXCELL - 1
      NYCLM1 = NYCELL - 1
      CLAREA = XCELLD * YCELLD
C
C INITIALIZE FORCING FUNCTION TO ZERO
C
      NWORDS = NXCELL * NYCELL
      CALL SINVAL(IPRINT, NWORDS, ZEROES, FRCFNC, JFLAG)
C
C SET THE STARTING SUBREGIONAL EXTREME COORDINATES
C
      ISMALL = NXCELL
      JSMALL = NYCELL
      ILARGE = 0
      JLARGE = 0
C
C SET LOOPS TO GET COORDINATES OF THE CENTER OF THE SUBREGION
C
      DO 120 J = 1, NYCELL
         DO 110 I = 1, NXCELL
C
C CHECK FOR THIS CELL BEING IN SUBREGION -- IF SO, CHECK COORDINATES
C
            IF (JRGRID(I, J) .NE. KSBRG) GO TO 110
            IF (I .LT. ISMALL) ISMALL = I
            IF (J .LT. JSMALL) JSMALL = J
            IF (I .GT. ILARGE) ILARGE = I
            IF (J .GT. JLARGE) JLARGE = J
C
C END LOOPS
C
  110    CONTINUE
  120 CONTINUE
C
C CALCULATE CENTER COORDINATES
C
      ICENTR = (ILARGE + ISMALL) / 2
      JCENTR = (JLARGE + JSMALL) / 2
C
C SET OUTER STATION NUMBER AND DISTANCE, SET LOOP OVER STATIONS
C
      JDMOST = 0
      KSTAT = 0
      DO 130 K = 1, NSTATS
C
C CHECK FOR VALID READING AND GET STATION LOCATION
C
         IF (STAVAL(K) .EQ. RMISSV) GO TO 130
         KXCLL = IFIX(XSTATL(K)) + 1
         KYCLL = IFIX(YSTATL(K)) + 1
C
C CHECK FOR STATION IN SUBREGION
C
         IF (KXCLL .LE. 0) GO TO 130
         IF (KYCLL .LE. 0) GO TO 130
         IF (KXCLL .GT. NXCELL) GO TO 130
         IF (KYCLL .GT. NYCELL) GO TO 130
         IF (JRGRID(KXCLL, KYCLL) .NE. KSBRG) GO TO 130
C
C CALCULATE AND TEST DISTANCE
C
         JDTEST = (KXCLL - ICENTR) ** 2 + (KYCLL - JCENTR) ** 2
         IF (JDTEST .LT. JDMOST) GO TO 130
C
C SAVE DISTANCE AND STATION NUMBER AND END LOOP
C
         JDMOST = JDTEST
         KSTAT = K
  130 CONTINUE
C
C IF STATION FOUND, SAVE LOCATION AND VALUE AND RESET VALUE
C
      IF (KSTAT .EQ. 0) GO TO 952
      KSTAA = KSTAT
      STVALA = STAVAL(KSTAT)
      STAVAL(KSTAT) = RMISSV
C
C SET OUTER STATION NUMBER AND DISTANCE, SET LOOP OVER STATIONS
C
      JDMOST = 0
      KSTAT = 0
      DO 140 K = 1, NSTATS
C
C CHECK FOR VALID READING AND GET STATION LOCATION
C
         IF (STAVAL(K) .EQ. RMISSV) GO TO 140
         KXCLL = IFIX(XSTATL(K)) + 1
         KYCLL = IFIX(YSTATL(K)) + 1
C
C CHECK FOR STATION IN SUBREGION
C
         IF (KXCLL .LE. 0) GO TO 140
         IF (KYCLL .LE. 0) GO TO 140
         IF (KXCLL .GT. NXCELL) GO TO 140
         IF (KYCLL .GT. NYCELL) GO TO 140
         IF (JRGRID(KXCLL, KYCLL) .NE. KSBRG) GO TO 140
C
C CALCULATE AND TEST DISTANCE
C
         JDTEST = (KXCLL - ICENTR) ** 2 + (KYCLL - JCENTR) ** 2
         IF (JDTEST .LT. JDMOST) GO TO 140
C
C SAVE DISTANCE AND STATION NUMBER AND END LOOP
C
         JDMOST = JDTEST
         KSTAT = K
  140 CONTINUE
C
C IF STATION FOUND, SAVE LOCATION AND VALUE AND RESET VALUE
C
      IF (KSTAT .EQ. 0) GO TO 954
      KSTAB = KSTAT
      STVALB = STAVAL(KSTAT)
      STAVAL(KSTAT) = RMISSV
C
C SET OUTER STATION NUMBER AND DISTANCE, SET LOOP OVER STATIONS
C
      JDMOST = 0
      KSTAT = 0
      DO 150 K = 1, NSTATS
C
C CHECK FOR VALID READING AND GET STATION LOCATION
C
         IF (STAVAL(K) .EQ. RMISSV) GO TO 150
         KXCLL = IFIX(XSTATL(K)) + 1
         KYCLL = IFIX(YSTATL(K)) + 1
C
C CHECK FOR STATION IN SUBREGION
C
         IF (KXCLL .LE. 0) GO TO 150
         IF (KYCLL .LE. 0) GO TO 150
         IF (KXCLL .GT. NXCELL) GO TO 150
         IF (KYCLL .GT. NYCELL) GO TO 150
         IF (JRGRID(KXCLL, KYCLL) .NE. KSBRG) GO TO 150
C
C CALCULATE AND TEST DISTANCE
C
         JDTEST = (KXCLL - ICENTR) ** 2 + (KYCLL - JCENTR) ** 2
         IF (JDTEST .LT. JDMOST) GO TO 150
C
C SAVE DISTANCE AND STATION NUMBER AND END LOOP
C
         JDMOST = JDTEST
         KSTAT = K
  150 CONTINUE
C
C IF STATION FOUND, SAVE LOCATION AND VALUE AND RESET VALUE
C
      IF (KSTAT .EQ. 0) GO TO 956
      KSTAC = KSTAT
      STVALC = STAVAL(KSTAT)
      STAVAL(KSTAT) = RMISSV
C
C RESTORE STATION VALUES
C
      STAVAL(KSTAA) = STVALA
      STAVAL(KSTAB) = STVALB
      STAVAL(KSTAC) = STVALC
C
C SET THE COORDINATES OF THE THREE STATIONS
C
      KXCLA = IFIX(XSTATL(KSTAA)) + 1
      KXCLB = IFIX(XSTATL(KSTAB)) + 1
      KXCLC = IFIX(XSTATL(KSTAC)) + 1
      KYCLA = IFIX(YSTATL(KSTAA)) + 1
      KYCLB = IFIX(YSTATL(KSTAB)) + 1
      KYCLC = IFIX(YSTATL(KSTAC)) + 1
C
C CALCULATE THE COEFFICIENTS OF THE PLANE
C
      ACOEFF = (FLOAT(KYCLC - KYCLB) * (STVALA - STVALB) -
     $          FLOAT(KYCLA - KYCLB) * (STVALC - STVALB)) /
     $         FLOAT((KYCLC - KYCLB) * (KXCLA - KXCLB) -
     $               (KYCLA -KYCLB) * (KXCLC - KXCLB))
      BCOEFF = (STVALA - STVALB - ACOEFF * FLOAT(KXCLA - KXCLB)) /
     $         FLOAT(KYCLA - KYCLB)
      CCOEFF = STVALA - ACOEFF * FLOAT(KXCLA) - BCOEFF * FLOAT(KYCLA)
C
C INITIALIZE THE CELLS OF THIS SUBREGION
C
      DO 180 J = 1, NYCELL
         DO 170 I = 1, NXCELL
            IF (JRGRID (I, J) .NE. KSBRG) GO TO 170
            OUTMAT(I, J) = ACOEFF * FLOAT(I) + BCOEFF * FLOAT(J) +
     $                     CCOEFF
  170    CONTINUE
  180 CONTINUE
C
C SET LOOP TO PLACE STATIONS IN GRID -- SKIP IF STATION VALUE MISSING
C
      DO 200 J = 1, NSTATS
         IF (STAVAL(J) .EQ. RMISSV) GO TO 200
C
C LOCATE STATION ON GRID
C
         KSTAT = J
         KXLOC = IFIX(XSTATL(J)) + 1
         KYLOC = IFIX(YSTATL(J)) + 1
C
C CHECK LOCATION IN REGION
C
         IF (KXLOC .LT. 1) GO TO 200
         IF (KXLOC .GT. NXCELL) GO TO 200
         IF (KYLOC .LT. 1) GO TO 200
         IF (KYLOC .GT. NYCELL) GO TO 200
         IF (JRGRID(KXLOC, KYLOC) .NE. KSBRG) GO TO 200
C
C STATION IS ACCEPTABLE -- SET VALUE AND NEGATE CELL TO KEEP VALUE
C
         OUTMAT(KXLOC, KYLOC) = STAVAL(J)
         JRGRID(KXLOC, KYLOC) = -JRGRID(KXLOC, KYLOC)
C
C END LOOP
C
  200 CONTINUE
C
C SET OUTER LOOP FOR POISSON ITERATION AND INITIALIZE RESIDUAL
C
      DO 300 K = 1, NMAXIT
         RESMAX = 0.0
C
C SET LOOPS OVER GRID
C
         DO 220 J = 2, NYCLM1
            DO 210 I = 2, NXCLM1
C
C IF CELL CONTAINS STATION OR IS IN ANOTHER SUBREGION, SKIP IT
C
               IF (JRGRID(I,J) .NE. KSBRG) GO TO 210
C
C IF ADJACENT CELLS ARE NOT ALL IN SUBREGION, SKIP THIS CELL
C
               IF (IABS(JRGRID(I+1,J)) .NE. KSBRG) GO TO 210
               IF (IABS(JRGRID(I-1,J)) .NE. KSBRG) GO TO 210
               IF (IABS(JRGRID(I,J+1)) .NE. KSBRG) GO TO 210
               IF (IABS(JRGRID(I,J-1)) .NE. KSBRG) GO TO 210
C
C SET DEVIATION AND CHECK RESIDUAL
C
               VALDEV = OUTMAT(I+1,J) + OUTMAT(I-1,J) +
     $                  OUTMAT(I,J+1) + OUTMAT(I,J-1) -
     $                  4.0 * OUTMAT(I,J)
               IF (ABS(VALDEV) .GT. ABS(RESMAX)) RESMAX = VALDEV
C
C ADJUST OUTPUT VALUE AND END INNER LOOPS
C
               OUTMAT(I,J) = OUTMAT(I,J) + WOMEGA * VALDEV
  210       CONTINUE
  220    CONTINUE
C
C CHECK THE RESIDUAL FOR EXCEEDING THE TOLERANCE
C
         IF (ABS(RESMAX) .LE. TLRNCE) GO TO 305
C
C END LOOP AND WRITE ERROR MESSAGE
C
  300 CONTINUE
      GO TO 970
C
C SET LOOPS TO CREATE INITIAL FORCING FUNCTION AT STATIONS
C
  305 DO 320 J = 2, NYCLM1
         DO 310 I = 2, NXCLM1
C
C TEST FOR STATION -- IF SO, TEST FOR BEING ON EDGE OF SUBREGION
C
            IF (JRGRID(I,J) .NE. -KSBRG) GO TO 310
            IF (IABS(JRGRID(I+1,J)) .NE. IABS(KSBRG)) GO TO 310
            IF (IABS(JRGRID(I-1,J)) .NE. IABS(KSBRG)) GO TO 310
            IF (IABS(JRGRID(I,J+1)) .NE. IABS(KSBRG)) GO TO 310
            IF (IABS(JRGRID(I,J-1)) .NE. IABS(KSBRG)) GO TO 310
C
C CALCULATE THE FORCING FUNCTION
C
            FRCFNC(I,J) = (OUTMAT(I+1,J) + OUTMAT(I,J+1) +
     $                     OUTMAT(I-1,J) + OUTMAT(I,J-1) -
     $                    4.0 * OUTMAT(I,J)) / CLAREA
C
C END LOOPS AND SET LOOP TO SPREAD FORCING FUNCTION
C
  310    CONTINUE
  320 CONTINUE
      DO 370 K = 1, NFORCE
C
C SET LOOPS TO COVER ENTIRE GRID IN FORWARD DIRECTION
C
         DO 340 J = 1, NYCLM1
            DO 330 I = 1, NXCLM1
C
C TEST FOR CORRECT SUBREGION AND NOT ON EDGE
C
               IF (IABS(JRGRID(I,J)) .NE. IABS(KSBRG)) GO TO 330
               IF (IABS(JRGRID(I+1,J)) .NE. IABS(KSBRG)) GO TO 330
               IF (IABS(JRGRID(I,J+1)) .NE. IABS(KSBRG)) GO TO 330
               IF (IABS(JRGRID(I+1,J+1)) .NE. IABS(KSBRG)) GO TO 330
C
C CALCULATE THE FORCING FUNCTION
C
               FRCFNC(I,J) = (FRCFNC(I,J) + FRCFNC(I+1,J) +
     $                       FRCFNC(I,J+1) + FRCFNC(I+1,J+1)) * 0.25
C
C END INNER LOOPS
C
  330      CONTINUE
  340    CONTINUE
C
C SET LOOPS TO COVER ENTIRE GRID IN BACKWARD DIRECTION
C
         DO 360 J = 2, NYCELL
            DO 350 I = 2, NXCELL
C
C TEST FOR CORRECT SUBREGION AND NOT ON EDGE
C
               IF (IABS(JRGRID(I,J)) .NE. IABS(KSBRG)) GO TO 350
               IF (IABS(JRGRID(I-1,J)) .NE. IABS(KSBRG)) GO TO 350
               IF (IABS(JRGRID(I,J-1)) .NE. IABS(KSBRG)) GO TO 350
               IF (IABS(JRGRID(I-1,J-1)) .NE. IABS(KSBRG)) GO TO 350
C
C CALCULATE THE FORCING FUNCTION
C
               FRCFNC(I,J) = (FRCFNC(I,J) + FRCFNC(I-1,J) +
     $                       FRCFNC(I,J-1) + FRCFNC(I-1,J-1)) * 0.25
C
C END ALL LOOPS
C
  350       CONTINUE
  360    CONTINUE
  370 CONTINUE
C
C SET OUTER LOOP FOR REPEAT OF POISSON ITERATION AND INITIALIZE RESIDUAL
C
      DO 500 K = 1, NMAXIT
         RESMAX = 0.0
C
C SET LOOPS OVER GRID
C
         DO 420 J = 2, NYCLM1
            DO 410 I = 2, NXCLM1
C
C IF CELL CONTAINS STATION OR IS IN ANOTHER SUBREGION, SKIP IT
C
               IF (JRGRID(I,J) .NE. KSBRG) GO TO 410
C
C IF ADJACENT CELLS ARE NOT ALL IN SUBREGION, SKIP THIS CELL
C
               IF (IABS(JRGRID(I+1,J)) .NE. KSBRG) GO TO 410
               IF (IABS(JRGRID(I-1,J)) .NE. KSBRG) GO TO 410
               IF (IABS(JRGRID(I,J+1)) .NE. KSBRG) GO TO 410
               IF (IABS(JRGRID(I,J-1)) .NE. KSBRG) GO TO 410
C
C SET DEVIATION
C
               VALDEV = OUTMAT(I+1,J) + OUTMAT(I-1,J) +
     $                  OUTMAT(I,J+1) + OUTMAT(I,J-1) -
     $                  4.0 * OUTMAT(I,J)
C
C FORCE DEVIATION AND CHECK RESIDUAL
C
               VALDEV = VALDEV - CLAREA * FRCFNC(I,J)
               IF (ABS(VALDEV) .GT. ABS(RESMAX)) RESMAX = VALDEV
C
C ADJUST OUTPUT VALUE AND END INNER LOOPS
C
               OUTMAT(I,J) = OUTMAT(I,J) + WOMEGA * VALDEV
  410       CONTINUE
  420    CONTINUE
C
C CHECK THE RESIDUAL FOR EXCEEDING THE TOLERANCE
C
         IF (ABS(RESMAX) .LE. TLRNCE) GO TO 505
C
C END LOOP AND WRITE ERROR MESSAGE
C
  500 CONTINUE
      GO TO 975
C
C SET LOOP TO RESET REGION GRID TO ALL POSITIVE
C
  505 DO 520 J = 1, NYCELL
         DO 510 I = 1, NXCELL
            JRGRID(I,J) = IABS(JRGRID(I,J))
  510    CONTINUE
  520 CONTINUE
C
C SET LOOPS TO VERIFY VALUES AND CHECK SUBREGION
C
      DO 540 J = 1, NYCELL
         DO 530 I = 1, NXCELL
            IF (JRGRID(I,J) .NE. KSBRG) GO TO 530
C
C CHECK VALUE AGAINST RANGE -- MESSAGE IF OUTSIDE
C
            IF (OUTMAT(I,J) .GT. VALMIN) GO TO 525
            IF (VALMIN .EQ. RMISSV) GO TO 525
      ILOW = ILOW + 1
      IF (ILOW - ILOW/10*10 .EQ. 1)
     $           WRITE (IPRINT,2525) MVARBL, I, J, VALMIN
            OUTMAT(I,J) = VALMIN
            GO TO 530
  525       IF (OUTMAT(I,J) .LE. VALMAX) GO TO 530
            IF (VALMAX .EQ. RMISSV) GO TO 530
      IHI = IHI + 1
      IF (IHI - (IHI/10*10) .EQ. 1)
     $             WRITE (IPRINT,2535) MVARBL, I, J, VALMAX
            OUTMAT(I,J) = VALMAX
C
C END LOOPS
C
  530    CONTINUE
  540 CONTINUE
C
C RETURN TO CALLING ROUTINE
C
      GO TO 1000
C
C ERROR MESSAGE FOR NO OUTERMOST STATION -- FIRST TRY
C
  952 WRITE (IPRINT, 2952) MSBRGN, MVARBL
      JFLAG = -11
      GO TO 1000
C
C ERROR MESSAGE FOR NO OUTERMOST STATION -- SECOND TRY
C
  954 WRITE (IPRINT, 2954) MSBRGN, MVARBL
      JFLAG = -12
      GO TO 1000
C
C ERROR MESSAGE FOR NO OUTERMOST STATION -- THIRD TRY
C
  956 WRITE (IPRINT, 2956) MSBRGN, MVARBL
      JFLAG = -13
      GO TO 1000
C
C ERROR MESSAGE FOR FAILURE TO CONVERGE ON INITIAL TRIAL
C
  970 WRITE (IPRINT, 2970) NMAXIT, TLRNCE, MVARBL
      JFLAG = -16
      GO TO 1000
C
C ERROR MESSAGE FOR FAILURE TO CONVERGE ON FORCING TRIAL
C
  975 WRITE (IPRINT, 2975) NMAXIT, TLRNCE, MVARBL
      JFLAG = -17
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 2525 FORMAT (42H ****** NOTE ****** THE VALUE OF VARIABLE , 10A1,
     $        10H IN CELL (, I10, 1H,, I10, 1H) //,
     $        42H IS BELOW THE MINIMUM ACCEPTABLE VALUE OF , F12.4,
     $        39H.  VALUE HAS BEEN RESET TO THE MINIMUM , //)
 2535 FORMAT (42H ****** NOTE ****** THE VALUE OF VARIABLE , 10A1,
     $        10H IN CELL (, I10, 1H,, I10, 1H) //,
     $        42H IS ABOVE THE MAXIMUM ACCEPTABLE VALUE OF , F12.4,
     $        39H.  VALUE HAS BEEN RESET TO THE MAXIMUM , //)
 2952 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        50H UNABLE TO LOCATE ANY VALID STATIONS IN SUBREGION ,
     $        10A1, 14H FOR VARIABLE , 10A1, //, 17H ON FIRST TRY.   ,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2954 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        50H UNABLE TO LOCATE ANY VALID STATIONS IN SUBREGION ,
     $        10A1, 14H FOR VARIABLE , 10A1, //, 17H ON SECOND TRY.   ,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2956 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        50H UNABLE TO LOCATE ANY VALID STATIONS IN SUBREGION ,
     $        10A1, 14H FOR VARIABLE , 10A1, //, 17H ON THIRD TRY.    ,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2970 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        41H SUBROUTINE POISVR FAILED TO CONVERGE IN , I10, //,
     $        30H ITERATIONS AT A TOLERANCE OF , F10.4,
     $        14H FOR VARIABLE , 10A1, 16H ON FIRST TRIAL ,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2975 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        41H SUBROUTINE POISVR FAILED TO CONVERGE IN , I10, //,
     $        30H ITERATIONS AT A TOLERANCE OF , F10.4,
     $        14H FOR VARIABLE , 10A1, 17H ON SECOND TRIAL ,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
      END
